#[repr(transparent)]pub struct BaseAddr0(pub u32);Expand description
Base Address for region 0 register
Tuple Fields
0: u32Implementations
Sourceimpl BaseAddr0
impl BaseAddr0
Sourcepub const fn addr_fixed(&self) -> u32
pub const fn addr_fixed(&self) -> u32
Fixed portion of the base address of region 0.
Sourcepub const fn set_addr_fixed(&mut self, val: u32)
pub const fn set_addr_fixed(&mut self, val: u32)
Fixed portion of the base address of region 0.
Sourcepub const fn set_addr_prg(&mut self, val: u8)
pub const fn set_addr_prg(&mut self, val: u8)
Programmable portion of the base address of region 0.